==> 0.0.5.tar.gz: example/my_pub_package/lib/self_contained.dart <==
library self_contained;

import 'package:ebisu/ebisu_utils.dart' as ebisu_utils;
// custom <additional imports>
// end <additional imports>


/// An address composed of zip, street and street number
class Address {
  String zip;
  String street;
  int streetNumber;

  // custom <class Address>
  // end <class Address>

  Map toJson() {
    return {
    "zip": ebisu_utils.toJson(zip),
    "street": ebisu_utils.toJson(street),
    "streetNumber": ebisu_utils.toJson(streetNumber),
    };
  }

  static Address fromJson(String json) {
    Map jsonMap = convert.JSON.decode(json);
    Address result = new Address();
    result._fromJsonMapImpl(jsonMap);
    return result;
  }

  static Address fromJsonMap(Map jsonMap) {
    Address result = new Address();
    result._fromJsonMapImpl(jsonMap);
    return result;
  }

  void _fromJsonMapImpl(Map jsonMap) {
    zip = jsonMap["zip"];
    street = jsonMap["street"];
    streetNumber = jsonMap["streetNumber"];
  }
}

class AddressBook {
  Map<String,Address> book = {};

  // custom <class AddressBook>
  // end <class AddressBook>

  Map toJson() {
    return {
    "book": ebisu_utils.toJson(book),
    };
  }

  static AddressBook fromJson(String json) {
    Map jsonMap = convert.JSON.decode(json);
    AddressBook result = new AddressBook();
    result._fromJsonMapImpl(jsonMap);
    return result;
  }

  static AddressBook fromJsonMap(Map jsonMap) {
    AddressBook result = new AddressBook();
    result._fromJsonMapImpl(jsonMap);
    return result;
  }

  void _fromJsonMapImpl(Map jsonMap) {
    // book map of <String, Address>
    book = { };
    jsonMap["book"].forEach((k,v) {
      book[k] = Address.fromJsonMap(v);
    });
  }
}

// custom <library self_contained>
// end <library self_contained>

==> 0.0.9.tar.gz: example/my_pub_package/lib/self_contained.dart <==
library self_contained;

import 'dart:convert' as convert;
import 'package:ebisu/ebisu_utils.dart' as ebisu_utils;
// custom <additional imports>
// end <additional imports>


/// An address composed of zip, street and street number
class Address {

  Address._json();

  String zip;
  String street;
  int streetNumber;

  // custom <class Address>
  // end <class Address>

  Map toJson() {
    return {
    "zip": ebisu_utils.toJson(zip),
    "street": ebisu_utils.toJson(street),
    "streetNumber": ebisu_utils.toJson(streetNumber),
    };
  }

  static Address fromJson(String json) {
    if(json == null) return null;
    Map jsonMap = convert.JSON.decode(json);
    Address result = new Address._json();
    result._fromJsonMapImpl(jsonMap);
    return result;
  }

  static Address fromJsonMap(Map jsonMap) {
    if(jsonMap == null) return null;
    Address result = new Address._json();
    result._fromJsonMapImpl(jsonMap);
    return result;
  }

  void _fromJsonMapImpl(Map jsonMap) {
    zip = jsonMap["zip"];
    street = jsonMap["street"];
    streetNumber = jsonMap["streetNumber"];
  }

}

class AddressBook {

  AddressBook._json();

  Map<String,Address> book = {};

  // custom <class AddressBook>
  // end <class AddressBook>

  Map toJson() {
    return {
    "book": ebisu_utils.toJson(book),
    };
  }

  static AddressBook fromJson(String json) {
    if(json == null) return null;
    Map jsonMap = convert.JSON.decode(json);
    AddressBook result = new AddressBook._json();
    result._fromJsonMapImpl(jsonMap);
    return result;
  }

  static AddressBook fromJsonMap(Map jsonMap) {
    if(jsonMap == null) return null;
    AddressBook result = new AddressBook._json();
    result._fromJsonMapImpl(jsonMap);
    return result;
  }

  void _fromJsonMapImpl(Map jsonMap) {

    // book is Map<String,Address>
    book = {};
    jsonMap["book"].forEach((k,v) {
      book[
        k
      ] = (v is Map)?
      Address.fromJsonMap(v) :
      Address.fromJson(v);
    });
  }

}

// custom <library self_contained>
// end <library self_contained>
